@@ -1,14 +1,14 @@
 package Datahub::Factory::Exporter::Arthub;
 
-use Datahub::Factory::Sane;
+use strict;
+use warnings;
 
-our $VERSION = '0.100';
+use Datahub::Factory::Sane;
 
 use Lido::XML;
 use Moo;
 use Catmandu;
 use namespace::clean;
-use Catmandu::BadVal;
 
 with 'Datahub::Factory::Exporter';
 
@@ -36,29 +36,8 @@ sub _build_out {
 sub add {
     my ($self, $item) = @_;
 
-    # Fall back system to determine the ID.
-    #  - If multiple LidoRecID's are present, use the 'preferred' one if this exists.
-    #  - If no preferred id's are defined, use the first one we'll encounter.
-    #  - If there's only one LidoRecID, use that one regardless of it's type.
-    my $id;
-    if (!exists($item->{'lidoRecID'})) {
-        Catmandu::BadVal->throw('No LidoRecID element found in document.');
-    }
-
-    if (scalar($item->{'lidoRecID'}) > 1) {
-        my @matches = grep { 'preferred' eq $_->{pref} } @{ $item->{'lidoRecID'} };
-        if (@matches) {
-            my $lidoRecID = pop @matches;
-            $id = $lidoRecID->{'_'};
-        } else {
-            $id = $item->{'lidoRecID'}->[0]->{'_'};
-        }
-    } else {
-        $id = $item->{'lidoRecID'}->[0]->{'_'};
-    }
-
     my $data = {
-        'id' => $id,
+        'id' => $item->{'lidoRecID'}->[0]->{'_'},
         '_'  => $self->lido->to_xml($item)
     };
 
